@@ -73,11 +73,10 @@ class MarkupField(models.TextField):
         # rules below.
         self.add_rendered_field = not kwargs.pop('no_rendered_field', False)
         super(MarkupField, self).__init__(*args, **kwargs)
-    
+
     def contribute_to_class(self, cls, name):
-        if self.add_rendered_field:
-            rendered_field = models.TextField(editable=False)
-            rendered_field.creation_counter = self.creation_counter+1
+        if self.add_rendered_field and not cls._meta.abstract:
+            rendered_field = models.TextField(editable=False, blank=True)
             cls.add_to_class(_rendered_field_name(name), rendered_field)
         super(MarkupField, self).contribute_to_class(cls, name)
         setattr(cls, self.name, MarkupDescriptor(self))
@@ -92,7 +91,9 @@ class MarkupField(models.TextField):
         value = self._get_val_from_obj(obj)
         return value.raw
 
-    def get_db_prep_value(self, value):
+    # this method should be renamed to get_prep_value but
+    # for django 1.1 compatibility only signature is updated
+    def get_db_prep_value(self, value, connection=None, prepared=False):
         try:
             return value.raw
         except AttributeError:
