@@ -1,7 +1,7 @@
 """
 widgets for django-markitup
 
-Time-stamp: <2010-01-06 12:31:06 carljm widgets.py>
+Time-stamp: <2011-04-19 19:03:14 carljm widgets.py>
 
 """
 from django import forms
@@ -32,11 +32,11 @@ class MarkItUpWidget(MarkupTextarea):
     Takes two additional optional keyword arguments:
 
     ``markitup_set``
-        URL path (absolute or relative to MEDIA_URL) to MarkItUp
+        URL path (absolute or relative to STATIC_URL) to MarkItUp
         button set directory.  Default: value of MARKITUP_SET setting.
 
     ``markitup_skin``
-        URL path (absolute or relative to MEDIA_URL) to MarkItUp skin
+        URL path (absolute or relative to STATIC_URL) to MarkItUp skin
         directory.  Default: value of MARKITUP_SKIN setting.
 
     """
@@ -55,7 +55,8 @@ class MarkItUpWidget(MarkupTextarea):
         return forms.Media(
             css= {'screen': (posixpath.join(self.miu_skin, 'style.css'),
                              posixpath.join(self.miu_set, 'style.css'))},
-            js=(settings.JQUERY_URL,
+            js=(absolute_url(settings.JQUERY_URL),
+                absolute_url('markitup/ajax_csrf.js'),
                 absolute_url('markitup/jquery.markitup.js'),
                 posixpath.join(self.miu_set, 'set.js')))
     media = property(_media)
